clear 
est clear

********************************************************************************
*	Programs
********************************************************************************

* program for the OLS regressions... 
capture program drop lm_regs
program define lm_regs, eclass

	*** Syntax 
	syntax varlist(numeric) [, y_bl(varlist numeric) ctrls(varlist numeric) treatment(varlist numeric) rounds(numlist) t_suff(string)] // adj(string)

	*** Unadjusted Regressions 
qui{
	foreach y of local varlist {
		foreach r in `rounds' {
		*** Create the centered block variables 
			capture drop blocks*
			qui tab block, gen(blocks)
			qui foreach v of varlist blocks* {
					replace `v' = . 			if missing(`y')
					su `v' 						if round == `r' & !missing(`y')
					replace `v' = `v' - r(mean) if round == `r' & !missing(`y')
				}
		*** Linear Model: treatment, Block FE, Cluster SEs at Club level, weights (tracking) 
		eststo `y'_`t_suff'_`r':		reg `y' b0.`treatment'##c.(blocks*) [pw=w] if round==`r', vce(cluster club)
			qui {
				*** add scalars
				* control mean
				qui su `y' [aw=w] if `treatment'==0 & round==`r'   
				estadd scalar c_mean = r(mean) 	
				estadd scalar c_sd = r(sd)
				* p-value 
				test 1.`treatment' == 0 
				estadd scalar pval = r(p) 
			}
		drop blocks*
		}
	}
}
	**** Adjusted Regressions 
qui {
	foreach y of local varlist {
		foreach r in `rounds' {
		*** Create the centered block variables 
			capture drop blocks*
			qui tab block, gen(blocks)
			qui foreach v of varlist blocks* {
					su `v' 						if round == `r' & !missing(`y')
					replace `v' = `v' - r(mean) if round == `r' & !missing(`y')
				}
		*** Linear Model: treatment, Block FE, Cluster SEs at Club level, weights (tracking), BL covars fully interacted
		eststo `y'_`t_suff'_`r'_adj:	reg `y' b0.`treatment'##c.(`ctrls' `y_bl' blocks*) [pw=w] if round==`r', vce(cluster club)
			qui {
				*** add scalars
				* control mean
				qui su `y' [aw=w] if `treatment'==0 & round==`r'   
				estadd scalar c_mean = r(mean) 	
				estadd scalar c_sd = r(sd)
				* p-value 
				test 1.`treatment' == 0 
				estadd scalar pval = r(p) 
			}
			drop blocks*
		}
	}		
}
end


* program to extract q values for the outcomes specified BY round
capture program drop get_qvals
program define get_qvals, eclass

	*** Syntax 
	syntax varlist(numeric) [, rounds(numlist) adj(string) t_suff(string) method(string) iv(string)]

	*** if LATE change the suffix 
	if ("`iv'"=="yes") local t_suff = "iv"
	di "`t_suff'"
	
	*** Create vector of p-values
	* matrix to store them
	local varcount : word count `varlist'
	matrix pvals_tab = J(`varcount',1,.) 
	matrix colnames pvals_tab = pvals
	* loop over outcomes and rounds
	qui foreach r in `rounds' {
	    local i = 0
		foreach y of local varlist {
		    local ++i
			* restore estimates
			est restore `y'_`t_suff'_`r'`adj' 
			est replay
			* collect pvals in matrix 
			if ("`iv'"=="yes") {
				local beta = e(b)[1,"1.treat_ther"]
				local beta_se = sqrt(e(V)["1.treat_ther","1.treat_ther"])
				local beta_z = `beta'/`beta_se'
				local beta_p = 2*(1-normal(abs(`beta_z')))
				matrix pvals_tab[`i',1] = `beta_p'
				matrix list pvals_tab
			}
			else if ("`iv'"!="yes") {
				matrix list r(table)
				matrix pvals_tab[`i',1] = r(table)["pvalue","1.treat_`t_suff'"]
			}
			* save in a dataset 
			capture drop pvals`r'
			svmat pvals_tab, names(col)
			rename pvals pvals`r'
			
			*** get q-values  
			capture drop qvals`r'
			qqvalue pvals`r', method(`method') qvalue(qvals`r') 
		}
	}
	*** add to estimates 
	* loop over outcomes and rounds
	qui foreach r in `rounds' {
	    local i = 0
		foreach y of local varlist {
		    local ++i
			* restore estimates
			est restore `y'_`t_suff'_`r'`adj' 
			* add as a scalar
			local qv = qvals`r' in `i'
			di `qv'
			estadd scalar qval = `qv'
		}
	}
end






********************************************************************************
*	I - Impacts of Therapy vs. Control
********************************************************************************

use "${data}/Analysis_wide.dta", clear
distinct block club

*** is it easier in long mode? I think it might be...
keep         age_current? w? *_b block cr_id club treat treat_ther treat_cash
reshape long age_current  w, i(block cr_id club treat) j(round)

*** Merge in relevant covid vars 
merge 1:1 cr_id round using  "$data\SMU_CleanData_Panel_Public", nogen assert(match) keepusing(ct_* c19_*) // keep(match) 






**** Some Descriptives of the CT ***********************************************

*** Do they still have any savings?
* only one third... 
tab ct_anyleft round, col 

*** How many gave cash to family/friends? 
* most had to give some
tab ct_hadtogive round , col

*** Could they choose how to spend it? 
* msot still got to choose how to spent 'some' of it...
tab ct_choosespent round , col

*** Thinks Covid affected how to spend 
tab ct_covideffect round, col

*** Thinks the CT helped 
tab ct_helpcovid round , col
* and how? 
foreach v of varlist ct_helpC19_buymeds ct_helpC19_buyfood ct_helpC19_payrentbills ct_helpC19_supportfam ct_helpC19_invest ct_helpC19_other {
	tab `v' round , col
}


 
 


**** Impact of Covid ***********************************************************

*** prep covid vars 
* rename c19_* *
foreach v of varlist c19_getangry c19_argue c19_talkthrough c19_helpchores c19_fear {
	replace `v'=. if `v'<0
	tab `v' round , col 
}
* increased stress agree/partially agree  
replace c19_stress = . if c19_stress<0
gen c19_stress_agree = inlist(c19_stress,1) if !missing(c19_stress)
* hh lost income (all most some / none)
replace c19_lostincome = . if c19_lostincome<0
gen c19_income_some = inlist(c19_lostincome,1,2,3) if !missing(c19_lostincome)

*** value label of cash arm 
label define treat_cash 0 "IPT-G" 1 "IPT-G+", modify



*** Regressions of cash treatment compared to therapy 
* exclude c19_helpchores and c19_income_some
lm_regs  c19_getangry c19_argue c19_talkthrough  c19_fear c19_stress_agree c19_lostincome, ///
	rounds(2 3) treatment(treat_cash) t_suff("cash") ///
	y_bl(phq8_score_b) ctrls(age_b everpregnant_b evermarried_b PPI_score_b)

*** Q values 
get_qvals c19_getangry c19_argue c19_talkthrough c19_fear c19_stress_agree c19_lostincome, rounds(2 3) adj(" ") 	 t_suff("cash") method("simes")
get_qvals c19_getangry c19_argue c19_talkthrough c19_fear c19_stress_agree c19_lostincome, rounds(2 3) adj("_adj") t_suff("cash") method("simes")

*** unadjusted table
* Midline
#delimit ;
esttab 	c19_getangry_cash_2 
		c19_argue_cash_2  
		c19_talkthrough_cash_2
		c19_fear_cash_2 
		c19_stress_agree_cash_2 
		c19_lostincome_cash_2
	using "${tables}/results-covid2.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_cash) 
	stats(c_mean c_sd N pval qval, fmt(3 3 0 3 3)  
	label("IPT-G mean" "IPT-G SD" "Observations" "H0: IPT-G+=0 p-values" "\hspace{20pt}FDR adj. q-values")) 
	; 
#delimit cr 
* Endline
#delimit ;
esttab  c19_getangry_cash_3 
		c19_argue_cash_3  
		c19_talkthrough_cash_2
		c19_fear_cash_3 
		c19_stress_agree_cash_3 		
		c19_lostincome_cash_3
	using "${tables}/results-covid3.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_cash) 
	stats(c_mean c_sd N pval qval, fmt(3 3 0 3 3)  
	label("IPT-G mean" "IPT-G SD" "Observations" "H0: IPT-G+=0 p-values" "\hspace{20pt}FDR adj. q-values")) 
	; 
#delimit cr 

eststo clear 










 

*** Regressions of therapy compared to control

replace treat_ther = . if treat == 2

* exclude c19_helpchores and c19_income_some
qui lm_regs  c19_getangry c19_argue c19_talkthrough  c19_fear c19_stress_agree c19_lostincome, ///
	rounds(2 3) treatment(treat_ther) t_suff("ther") ///
	y_bl(phq8_score_b) ctrls(age_b everpregnant_b evermarried_b PPI_score_b)

*** Q values 
get_qvals c19_getangry c19_argue c19_talkthrough c19_fear c19_stress_agree c19_lostincome, rounds(2 3) adj(" ") 	 t_suff("ther") method("simes")
get_qvals c19_getangry c19_argue c19_talkthrough c19_fear c19_stress_agree c19_lostincome, rounds(2 3) adj("_adj") t_suff("ther") method("simes")

*** unadjusted table
* Midline
#delimit ;
esttab 	c19_getangry_ther_2 
		c19_argue_ther_2  
		c19_talkthrough_ther_2
		c19_fear_ther_2 
		c19_stress_agree_ther_2 
		c19_lostincome_ther_2
	using "${tables}/results-covid-thercontrol2.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_ther) 
	stats(c_mean c_sd N pval qval, fmt(3 3 0 3 3)  
	label("Control mean" "Control SD" "Observations" "H0: IPT-G=0 p-values" "\hspace{20pt}FDR adj. q-values")) 
	; 
#delimit cr 
* Endline
#delimit ;
esttab  c19_getangry_ther_3 
		c19_argue_ther_3  
		c19_talkthrough_ther_2
		c19_fear_ther_3 
		c19_stress_agree_ther_3 		
		c19_lostincome_ther_3
	using "${tables}/results-covid-thercontrol3.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_ther) 
	stats(c_mean c_sd N pval qval, fmt(3 3 0 3 3)  
	label("Control mean" "Control SD" "Observations" "H0: IPT-G=0 p-values" "\hspace{20pt}FDR adj. q-values")) 
	; 
#delimit cr 



