clear 
est clear

********************************************************************************
*	Programs
********************************************************************************

* program for the OLS regressions... 
capture program drop lm_regs
program define lm_regs, eclass

	*** Syntax 
	syntax varlist(numeric) [, y_bl(varlist numeric) ctrls(varlist numeric) treatment(varlist numeric) rounds(numlist) t_suff(string)]

	*** Unadjusted Regressions 
qui	{
	foreach y of local varlist {
		foreach r in `rounds' {
		*** Create the centered block variables 
			capture drop blocks*
			qui tab block, gen(blocks)
			qui foreach v of varlist blocks* {
					replace `v' = . 			if missing(`y') & round ==`r'
					su `v' 						if round == `r' & !missing(`y')
					replace `v' = `v' - r(mean) if round == `r' & !missing(`y')
				}
		*** Linear Model: treatment, Block FE, Cluster SEs at Club level, weights (tracking) 
		eststo `y'_`t_suff'_`r':		reg `y' b0.`treatment'##c.(blocks*) [pw=w] if round==`r', vce(cluster club)
			qui {
				*** add scalars
				* control mean
				qui su `y' [aw=w] if `treatment'==0 & round==`r' 
				estadd scalar c_mean = r(mean) 	
				estadd scalar c_sd = r(sd)
				* p-value 
				test 1.`treatment' == 0 
				estadd scalar pval = r(p) 
			}
		}
	}
}
	**** Adjusted Regressions 
qui {
	foreach y of local varlist {
		foreach r in `rounds' {
		*** Create the centered block variables 
			capture drop blocks*
			qui tab block, gen(blocks)
			qui foreach v of varlist blocks* {
					replace `v' = . 			if missing(`y')
					su `v' 						if round == `r' & !missing(`y')
					replace `v' = `v' - r(mean) if round == `r' & !missing(`y')
				}
		*** Linear Model: treatment, Block FE, Cluster SEs at Club level, weights (tracking), BL covars fully interacted
		eststo `y'_`t_suff'_`r'_adj:	reg `y' b0.`treatment'##c.(`ctrls' `y_bl' blocks*) [pw=w] if round==`r', vce(cluster club)
			qui {
				*** add scalars
				* control mean
				qui su `y' [aw=w] if `treatment'==0 & round==`r'   
				estadd scalar c_mean = r(mean) 	
				estadd scalar c_sd = r(sd)
				* p-value 
				test 1.`treatment' == 0 
				estadd scalar pval = r(p) 
			}
		}
	}
}
end





********************************************************************************
*	I - Impacts of Therapy vs. Control
********************************************************************************

use "${data}/Analysis_wide.dta", clear
distinct block club

*** is it easier in long mode? I think it might be...
reshape long phq8_score ghq12_score rosb_score res_score loc_score ghq12_min phq8_min w, i(block cr_id club treat ) j(round)

*** drop +cash folks in longer follow ups 
drop if treat==2 & round>=2
tab round 

*** Create the centered block variables 
qui tab block, gen(blocks)
qui foreach v of varlist blocks* {
	forvalues r = 1/3 {
		su `v' 						if round == `r'
		replace `v' = `v' - r(mean) if round == `r'
	}
}

*** create alternative indicators 
gen phq8_mdd = phq8_score >= 10
gen phq8_severe = phq8_score >= 15



*** run regs for main outcomes  
lm_regs phq8_mdd phq8_severe, ///
	treatment(treat_ther) t_suff("ther") y_bl(phq8_score_b)  ///
	ctrls(age_b everpregnant_b evermarried_b PPI_score_b) rounds(1 2 3)

*** Table
* RR
#delimit ;
esttab 	
		phq8_mdd_ther_1 
		phq8_mdd_ther_1_adj 
		phq8_severe_ther_1 
		phq8_severe_ther_1_adj 
	using "${tables}/results-mh-mdd1.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_ther) 
	stats(c_mean c_sd N pval, fmt(3 3 0 3)  
	label("Control mean" "Control SD" "Observations" "H0: IPT-G=0 p-values")) 
	; 
#delimit cr 
* Midline
#delimit ;
esttab 	
		phq8_mdd_ther_2 
		phq8_mdd_ther_2_adj 
		phq8_severe_ther_2
		phq8_severe_ther_2_adj 
	using "${tables}/results-mh-mdd2.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_ther) 
	stats(c_mean c_sd N pval, fmt(3 3 0 3)  
	label("Control mean" "Control SD" "Observations" "H0: IPT-G=0 p-values")) 
	; 
#delimit cr 
* Endline
#delimit ;
esttab 	
		phq8_mdd_ther_3 
		phq8_mdd_ther_3_adj 
		phq8_severe_ther_3 
		phq8_severe_ther_3_adj	
	using "${tables}/results-mh-mdd3.tex", replace  booktabs
	label nostar nonote nomtitle nonumber frag nolines nogaps
	b(3) se(3) keep(1.treat_ther) 
	stats(c_mean c_sd N pval, fmt(3 3 0 3)  
	label("Control mean" "Control SD" "Observations" "H0: IPT-G=0 p-values")) 
	; 
#delimit cr 	
